

import java.net.MalformedURLException;
import java.net.ProtocolException;
import java.net.URL;
import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;
import java.net.HttpURLConnection;
import org.json.simple.parser.JSONParser;
import org.json.simple.parser.ParseException;
import org.json.simple.JSONArray;
import org.json.simple.JSONObject;

public class Location {

	private double latitude;
	private double longitude;
	private String city;
	private JSONObject jsonInfo;

	/**
	 * Manual location constructor
	 * @param lat
	 * @param lon
	 * @param city
	 */
	public Location(double lat, double lon, String city) {
		latitude = lat;
		longitude = lon;
        this.city = city;
	}

	/**
	 * Initialize with automatic online info from (ip-api.com).
	 */
	public Location() {
		jsonInfo = apiInformationObject();
		this.city = jsonInfo.get(API_Keys.city.name()).toString();
		this.latitude = (double)jsonInfo.get(API_Keys.lat.name());
		this.longitude = (double)jsonInfo.get(API_Keys.lon.name());

    }
	
	public double getLatitude() {
		return latitude;
	}
	
	public String getCity() {
		return city;
	}

	public void setLatitude(double latitude) {
		this.latitude = latitude;
	}
	
	public double getLongitude() {
		return longitude;
	}
	
	public void setLongitude(double longitude) {
		this.longitude = longitude;
	}
	
	public void setLocation(double lat, double lon) {
		this.latitude = lat;
		this.longitude = lon;
	}


	/**
	 * @deprecated
	 * @return
	 */
	public String cityBasedOnIP() {
		String city = "";
		try {
			
			URL url = new URL("http://ip-api.com/json");
			HttpURLConnection con = (HttpURLConnection) url.openConnection();
			con.setRequestMethod("GET");
			con.setRequestProperty("Content-Type", "application/json");
			int status = con.getResponseCode();
			BufferedReader in = new BufferedReader(
					  new InputStreamReader(con.getInputStream()));
			String inputLine;
			StringBuffer content = new StringBuffer();
			while ((inputLine = in.readLine()) != null) {
			    content.append(inputLine);
			}
			in.close();
			
			 JSONParser parser = new JSONParser();
             Object resultObject = parser.parse(content.toString());

             if (resultObject instanceof JSONArray) {
                 JSONArray array=(JSONArray)resultObject;
                 for (Object object : array) {
                     JSONObject obj =(JSONObject)object;
                     city = (String)obj.get(API_Keys.city.name());
                 }

             }
             else if (resultObject instanceof JSONObject) {
                 JSONObject obj =(JSONObject)resultObject;
                 city = (String)obj.get(API_Keys.city.name());
			 }
		}
		catch (MalformedURLException e) {
			e.printStackTrace();
		}
		catch (ProtocolException e) {
			e.printStackTrace();
		}
		catch (IOException e) {
			e.printStackTrace();
		}
		catch (ParseException e) {
			e.printStackTrace();
		}
		return city;
	}

	private JSONObject apiInformationObject(){
		JSONObject jsonObj = null;
		try {

			URL url = new URL("http://ip-api.com/json");
			HttpURLConnection con = (HttpURLConnection) url.openConnection();
			con.setRequestMethod("GET");
			con.setRequestProperty("Content-Type", "application/json");
			int status = con.getResponseCode();
			BufferedReader in = new BufferedReader(
					new InputStreamReader(con.getInputStream()));
			String inputLine;
			StringBuffer content = new StringBuffer();
			while ((inputLine = in.readLine()) != null) {
				content.append(inputLine);
			}
			in.close();

			JSONParser parser = new JSONParser();
			Object resultObject = parser.parse(content.toString());

			if (resultObject instanceof JSONArray) {
				JSONArray array=(JSONArray)resultObject;
				for (Object object : array) {
					jsonObj =(JSONObject)object;
				}

			}
			else if (resultObject instanceof JSONObject) {
				jsonObj =(JSONObject)resultObject;
			}
		}
		catch (MalformedURLException e) {
			e.printStackTrace();
		}
		catch (ProtocolException e) {
			e.printStackTrace();
		}
		catch (IOException e) {
			e.printStackTrace();
		}
		catch (ParseException e) {
			e.printStackTrace();
		}

		return jsonObj;
	}


	private  enum API_Keys {
		zip,
		country,
		city,
		org,
		timezone,
		isp,
		quary,
		regionName,
		lon,
		lat,
		as,
		countryCode,
		region,
		status
	}
}
